# wanha - your pesky URL-guardian for IRC
# Copyright (C) 2006 Tommi Saviranta  <wnd@iki.fi>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


package HTTP;

use strict;
use warnings FATAL => 'all';
use diagnostics;

require "lang.pl";
require "config.pl";

my %get_val;

my @cookies;
my %cookie_value;
my %cookie_expire;
my $redirect_location;


if (defined($ENV{"QUERY_STRING"})) {
	foreach $_ (split ('&', $ENV{"QUERY_STRING"})) {
		my $key;
		($key, $_) = /(.*)=(.*)/;
		(defined($key)) || next;
		tr/+/ /;
		s/%([a-fA-F0-9][a-fA-F0-9])/pack("C", hex($1))/eg;
		$get_val{$key} = $_;
	}
}


# 0: key
# 1: default
sub get
{
	my ($key, $def) = @_;
	my $val = $get_val{"$key"};
	if (defined($val)) {
		return $val;
	} else {
		return $def;
	}
}


# ...: cookies
sub get_cookies
{
	my @cookies;
	my $t = $ENV{"HTTP_COOKIE"};
	(defined($t)) || return;

	foreach $_ (split ('; ', $t)) {
		push(@cookies, $_);
	}
	return @cookies;
}


# ...: (name, value, age)
sub set_cookie
{
	while ($#_ >= 0) {
		my $age = pop(@_);
		my $value = pop(@_);
		my $name = pop(@_);
		push(@cookies, $name);
		$cookie_value{$name} = $value;
		$cookie_expire{$name} = $age;
	}
}


sub print_header
{
	my ($host, $path) = &Conf::base_url() =~ /.*?\/\/(.*?)(\/.*)/;
	my @mon_str = ("Jan", "Feb", "Mar", "Apr", "May", "Jun",
			"Jul", "Aug", "Sep", "Oct", "Nov", "Dec");
	my @day_str = ("Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat");
	print "Content-Type: text/html\n";
	print "Cache-Control: private\n";
	foreach my $key (@cookies) {
		my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday) =
				gmtime($cookie_expire{$key} + time());
		my $expr = sprintf "%s, %02d-%s-%d %02d:%02d:%02d GMT",
				$day_str[$wday],
				$mday, $mon_str[$mon], 1900 + $year,
				$hour, $min, $sec;
		printf "Set-Cookie: %s=%s; Path=%s; Host=%s; Expires=%s\n",
				$key, $cookie_value{$key},
				$path, $host, $expr;
	}
	(defined($redirect_location)) && print "Location: $redirect_location\n";
	print "\n";
}


# 0: location
sub redirect($)
{
	($redirect_location) = @_;
	$redirect_location =~ s/&amp;/\&/g;
}


return 1;
