# wanha - your pesky URL-guardian for IRC
# Copyright (C) 2006 Tommi Saviranta  <wnd@iki.fi>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


package Session;

use strict;
use warnings FATAL => 'all';
use diagnostics;

require "http.pl";
require "db.pl";
require "common.pl";


# r: sid
sub get_session($)
{
	my $sid;
	foreach my $line (&HTTP::get_cookies()) {
		my ($key, $val) = $line =~ /(.*?)=(.*)/;
		($key ne "sid") && next;
		$sid = $val;
	}

	if (! defined($sid)) {
		$sid = &HTTP::get("sid");
	}

	if (! defined($sid)) {
		return;
	}

	my ($query, $result);
	$query = "SELECT set FROM cookies WHERE sid = '$sid'";
	$result = &DB::query($query);

	($result->ntuples == 0) && return;

	# TODO
	# If cookies.set + cookies.age / 2 >= CURRENT_TIMESTAMP, update
	# cookies.set to make sure cookie won't be lost. Also send updated
	# cookie (http header)

	return $sid;
}


# 0: sid
# r: (latest url id, age, urls, set_date, reset)
sub get_cookie_info($)
{
	my ($sid) = @_;
	my ($query, $result);

	$query = "SELECT latest, age, urls, set, reset " .
			"FROM cookies WHERE sid = '$sid'";
	$result = &DB::query($query);
	($result->ntuples == 0) && return;

	my ($latest, $age, $urls, $set, $reset) = $result->fetchrow;
	$reset = ($reset eq "t") ? 1 : 0;

	return ($latest, $age, $urls, $set, $reset);
}


# 0: sid
# r: chan ...
sub get_ignore_chans($)
{
	my ($sid) = @_;
	my ($query, $result);
	my @ignore;

	$query = "SELECT chan FROM chan_ignore WHERE sid = '$sid'";

	$result = &DB::query($query);
	($result->ntuples == 0) && return ();

	while (my ($chan) = $result->fetchrow) {
		push(@ignore, $chan);
	}

	return @ignore;
}


sub get_latest_url_id()
{
	my ($query, $result);

	$query = "SELECT id FROM urls ORDER BY id DESC LIMIT 1";
	$result = &DB::query($query);

	my ($latest) = $result->fetchrow;

	return $latest;
}


# 0: sid
# 1: latest
sub set_latest($$)
{
	my ($sid, $id) = @_;
	my $query;

	$query = "UPDATE cookies SET latest = $id WHERE sid = '$sid'";
	&DB::update($query);
}


# 0: sid
sub new_cookie($)
{
	my ($sid) = @_;
	my $query;

	my $latest = &Common::max(0, &get_latest_url_id() - 100);

	$query = "INSERT INTO cookies (sid, latest) VALUES ('$sid', $latest)";
	&DB::update($query);
}


sub create_sid()
{
	my $try = 32;
	my $sid;
	my $used;

	for (1..16) { # try 16 sids
		$try--;
		my ($query, $result);
		my $a = rand() * (2 ** 24);
		my $b = rand() * (2 ** 24);
		my $c = rand() * (2 ** 24);
		$sid = sprintf "%06x%06x%06x", $a, $b, $c;
		$query = "SELECT sid FROM cookies WHERE sid = '$sid'";
		$result = &DB::query($query);
		if ($result->ntuples == 0) {
			&new_cookie($sid);
			return $sid;
		}
	}
	return;
}


return 1;
