# wanha - your pesky URL-guardian for IRC
# Copyright (C) 2006 Tommi Saviranta  <wnd@iki.fi>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


package URLList;

use strict;
use warnings FATAL => 'all';
use diagnostics;

require "html.pl";
require "db.pl";
require "dbops.pl";
require "url.pl";
require "common.pl";
require "lang.pl";


# 0: print first pasted: 0 = off, 1 = user, 2 = chan
# 1: show id
# ...: cvs (url_id, url_time, url_count, nick_id, nick_name, url)
# r: image urls
sub print
{
	my ($show_paste) = $_[0];
	my ($show_id) = $_[1] == 1 ? 1 : 0;
	shift; shift;
	my @urls = @_;

	my @images;

	my $l_id = $show_id == 1 ? "\n\t\t<th></th>" : "";
	my $l_add = &Lang::get("col-address");
	my $l_times = &Lang::get("col-times-pasted");
	my $col_first = "";
	if ($show_paste != 0) {
		my $l_first = &Lang::get("col-first-pasted");
		$col_first = "\n\t\t<th colspan=\"2\">$l_first</th>";
	}
	print <<EOF;
<table class="urls">
	<tr>$l_id
		<th>$l_add</th>$col_first
		<th>$l_times</th>
	</tr>
EOF
	my $i = 0;
	foreach (@urls) {
		# r: csv (url_id,url_time,url_count,paste_id,paste_name,url)
		my ($url_id, $url_date, $url_count, $paste_id, $paste_name,
				$url_url) = split(/,/, $_, 6);
		my ($paste_print, $paste_link);
		if ($show_paste == 1) {
			$paste_link = &URL::user($paste_id);
		} elsif ($show_paste == 2) {
			$paste_link = &URL::chan($paste_id);
		}
		my $p_url = &HTML::amp_url(&HTML::truncate_url($url_url));
		my $url_xhtml = &HTML::amp_url($url_url);
		(&Common::is_image == 1) && push(@images, $url_xhtml);
		my $class = $i % 2 == 1 ? " class=\"zebra\"" : "";
		my $id = $show_id == 1 ?
				"\n\t\t<td class=\"right\">#$url_id</td>" : "";
		print "\t\t<tr$class>$id\n";
		print "\t\t\t<td><a href=\"$url_xhtml\">$p_url</a></td>\n";
		if ($show_paste != 0) {
			print "\t\t\t<td><a href=\"$paste_link\">" .
					"$paste_name</a></td>\n";
			print "\t\t\t<td>$url_date</td>\n";
		}
		print "\t\t\t<td class=\"center\">$url_count</td>\n";
		print "\t\t</tr>\n";
		$i++;
	}
	print <<EOF;
</table>
EOF

	return @images;
}


return 1;
